@@ -36,7 +36,7 @@ struct target_node {
 	uint32_t client_id;
 	uint32_t id;
 	struct obs_pw_audio_proxy_list ports;
-	uint32_t *p_n_targets;
+	uint32_t *p_n_nodes;
 
 	struct spa_hook node_listener;
 };
@@ -63,7 +63,16 @@ struct capture_sink_port {
 	uint32_t id;
 };
 
-enum match_priority { BINARY_NAME, APP_NAME };
+enum capture_mode { CAPTURE_MODE_SINGLE, CAPTURE_MODE_MULTIPLE };
+enum match_priority { MATCH_PRIORITY_BINARY_NAME, MATCH_PRIORITY_APP_NAME };
+
+#define SETTING_CAPTURE_MODE "CaptureMode"
+#define SETTING_MATCH_PRIORITY "MatchPriorty"
+#define SETTING_EXCLUDE_SELECTIONS "ExceptApp"
+#define SETTING_SELECTION_SINGLE "TargetName"
+#define SETTING_SELECTION_MULTIPLE "apps"
+#define SETTING_AVAILABLE_APPS "AppToAdd"
+#define SETTING_ADD_TO_SELECTIONS "AddToSelected"
 
 /** This source basically works like this:
     - Keep track of output streams and their ports, system sinks and the default sink
@@ -74,6 +83,8 @@ enum match_priority { BINARY_NAME, APP_NAME };
     - Connect any registered or new stream ports to the sink
 */
 struct obs_pw_audio_capture_app {
+	obs_source_t *source;
+
 	struct obs_pw_audio_instance pw;
 
 	/** The app capture sink automatically mixes
@@ -104,12 +115,13 @@ struct obs_pw_audio_capture_app {
 
 	struct obs_pw_audio_proxy_list clients;
 
-	struct obs_pw_audio_proxy_list targets;
-	uint32_t n_targets;
+	struct obs_pw_audio_proxy_list nodes;
+	uint32_t n_nodes;
 
+	enum capture_mode capture_mode;
 	enum match_priority match_priority;
-	struct dstr target;
-	bool except_app;
+	bool except;
+	DARRAY(const char *) selections;
 };
 
 /* System sinks */
@@ -198,7 +210,7 @@ static void node_destroy_cb(void *data)
 
 	obs_pw_audio_proxy_list_clear(&node->ports);
 
-	(*node->p_n_targets)--;
+	(*node->p_n_nodes)--;
 
 	bfree((void *)node->binary);
 	bfree((void *)node->app_name);
@@ -259,40 +271,39 @@ static void register_target_node(struct obs_pw_audio_capture_app *pwac, uint32_t
 	node->binary = NULL;
 	node->id = global_id;
 	node->client_id = client_id;
-	node->p_n_targets = &pwac->n_targets;
+	node->p_n_nodes = &pwac->n_nodes;
 	obs_pw_audio_proxy_list_init(&node->ports, NULL, port_destroy_cb);
 
-	pwac->n_targets++;
+	pwac->n_nodes++;
 
-	obs_pw_audio_proxy_list_append(&pwac->targets, node_proxy);
+	obs_pw_audio_proxy_list_append(&pwac->nodes, node_proxy);
 	pw_proxy_add_object_listener(node_proxy, &node->node_listener, &node_events, node);
 }
 
 static bool node_is_targeted(struct obs_pw_audio_capture_app *pwac, struct target_node *node)
 {
-	if (dstr_is_empty(&pwac->target)) {
-		return false;
-	}
+	bool targeted = false;
+	for (size_t i = 0; i < pwac->selections.num && !targeted; i++) {
+		const char *selection = pwac->selections.array[i];
 
-	bool targeted = (dstr_cmpi(&pwac->target, node->binary) == 0 || dstr_cmpi(&pwac->target, node->app_name) == 0 ||
-					 dstr_cmpi(&pwac->target, node->name) == 0);
+		targeted = (astrcmpi(selection, node->binary) == 0 || astrcmpi(selection, node->app_name) == 0 ||
+					astrcmpi(selection, node->name) == 0);
 
-	if (!targeted && node->client_id) {
-		struct obs_pw_audio_proxy_list_iter iter;
-		obs_pw_audio_proxy_list_iter_init(&iter, &pwac->clients);
+		if (!targeted && node->client_id) {
+			struct obs_pw_audio_proxy_list_iter iter;
+			obs_pw_audio_proxy_list_iter_init(&iter, &pwac->clients);
 
-		struct target_client *client;
-		while (obs_pw_audio_proxy_list_iter_next(&iter, (void **)&client)) {
-			if (client->id == node->client_id) {
-				targeted =
-					(dstr_cmpi(&pwac->target, client->binary) == 0 || dstr_cmpi(&pwac->target, client->app_name) == 0);
-
-				break;
+			struct target_client *client;
+			while (obs_pw_audio_proxy_list_iter_next(&iter, (void **)&client)) {
+				if (client->id == node->client_id) {
+					targeted = (astrcmpi(selection, client->binary) == 0 || astrcmpi(selection, client->app_name) == 0);
+					break;
+				}
 			}
 		}
 	}
 
-	return targeted ^ pwac->except_app;
+	return targeted ^ pwac->except;
 }
 /* ------------------------------------------------- */
 
@@ -346,8 +357,6 @@ static void link_port_to_sink(struct obs_pw_audio_capture_app *pwac, struct targ
 														PW_VERSION_LINK, &link_props->dict,
 														sizeof(struct capture_sink_link));
 
-	obs_pw_audio_instance_sync(&pwac->pw);
-
 	pw_properties_free(link_props);
 
 	if (!link_proxy) {
@@ -443,26 +452,20 @@ static void destroy_sink_links(struct obs_pw_audio_capture_app *pwac)
 	obs_pw_audio_proxy_list_clear(&pwac->sink.links);
 }
 
-static void connect_targets(struct obs_pw_audio_capture_app *pwac, const char *target, bool except)
+static void connect_targets(struct obs_pw_audio_capture_app *pwac)
 {
-	pwac->except_app = except;
-
-	if (target) {
-		dstr_copy(&pwac->target, target);
-	}
-
 	if (!pwac->sink.proxy) {
 		return;
 	}
 
 	destroy_sink_links(pwac);
 
-	if (dstr_is_empty(&pwac->target)) {
+	if (pwac->selections.num == 0) {
 		return;
 	}
 
 	struct obs_pw_audio_proxy_list_iter iter;
-	obs_pw_audio_proxy_list_iter_init(&iter, &pwac->targets);
+	obs_pw_audio_proxy_list_iter_init(&iter, &pwac->nodes);
 
 	struct target_node *node;
 	while (obs_pw_audio_proxy_list_iter_next(&iter, (void **)&node)) {
@@ -481,18 +484,17 @@ static bool make_capture_sink(struct obs_pw_audio_capture_app *pwac, uint32_t ch
 	 * and because of https://gitlab.freedesktop.org/pipewire/pipewire/-/merge_requests/1564#note_1861698, which works the same for
 	 * deciding what nodes need an audio adapter.
 	 */
-	struct pw_properties *sink_props =
-		pw_properties_new(PW_KEY_NODE_NAME, "OBS", PW_KEY_NODE_DESCRIPTION, "OBS App Audio Capture Sink",
-						  PW_KEY_FACTORY_NAME, "support.null-audio-sink", PW_KEY_MEDIA_CLASS, "Audio/Sink/Internal",
-						  PW_KEY_NODE_VIRTUAL, "true", SPA_KEY_AUDIO_POSITION, position, NULL);
+	struct pw_properties *sink_props = pw_properties_new(PW_KEY_FACTORY_NAME, "support.null-audio-sink",
+														 PW_KEY_MEDIA_CLASS, "Audio/Sink/Internal", PW_KEY_NODE_VIRTUAL,
+														 "true", SPA_KEY_AUDIO_POSITION, position, NULL);
+
+	pw_properties_setf(sink_props, PW_KEY_NODE_NAME, "OBS: %s", obs_source_get_name(pwac->source));
 
 	pw_properties_setf(sink_props, PW_KEY_AUDIO_CHANNELS, "%u", channels);
 
 	pwac->sink.proxy =
 		pw_core_create_object(pwac->pw.core, "adapter", PW_TYPE_INTERFACE_Node, PW_VERSION_NODE, &sink_props->dict, 0);
 
-	obs_pw_audio_instance_sync(&pwac->pw);
-
 	pw_properties_free(sink_props);
 
 	if (!pwac->sink.proxy) {
@@ -521,7 +523,7 @@ static bool make_capture_sink(struct obs_pw_audio_capture_app *pwac, uint32_t ch
 	blog(LOG_INFO, "[pipewire] Created app capture sink %u with %u channels and position %s", pwac->sink.id, channels,
 		 position);
 
-	connect_targets(pwac, NULL, pwac->except_app);
+	connect_targets(pwac);
 
 	pwac->sink.autoconnect_targets = true;
 
@@ -547,7 +549,6 @@ static void destroy_capture_sink(struct obs_pw_audio_capture_app *pwac)
 
 	pwac->sink.autoconnect_targets = false;
 	pw_proxy_destroy(pwac->sink.proxy);
-	obs_pw_audio_instance_sync(&pwac->pw);
 }
 /* ------------------------------------------------- */
 
@@ -703,7 +704,7 @@ static void on_global_cb(void *data, uint32_t id, uint32_t permissions, const ch
 		} else if (astrcmpi(dir, "out") == 0) {
 			/* Possibly a target port */
 			struct obs_pw_audio_proxy_list_iter iter;
-			obs_pw_audio_proxy_list_iter_init(&iter, &pwac->targets);
+			obs_pw_audio_proxy_list_iter_init(&iter, &pwac->nodes);
 
 			struct target_node *temp, *node = NULL;
 			while (obs_pw_audio_proxy_list_iter_next(&iter, (void **)&temp)) {
@@ -772,40 +773,52 @@ static const struct pw_registry_events registry_events = {
 /* ------------------------------------------------- */
 
 /* Source */
-static void *pipewire_audio_capture_app_create(obs_data_t *settings, obs_source_t *source)
+static bool add_app_clicked(obs_properties_t *properties, obs_property_t *property, void *data)
 {
-	struct obs_pw_audio_capture_app *pwac = bzalloc(sizeof(struct obs_pw_audio_capture_app));
+	UNUSED_PARAMETER(properties);
+	UNUSED_PARAMETER(property);
 
-	if (!obs_pw_audio_instance_init(&pwac->pw, &registry_events, pwac, true, false, source)) {
-		obs_pw_audio_instance_destroy(&pwac->pw);
+	obs_source_t *source = data;
 
-		bfree(pwac);
-		return NULL;
+	obs_data_t *settings = obs_source_get_settings(source);
+	const char *app_to_add = obs_data_get_string(settings, SETTING_AVAILABLE_APPS);
+
+	obs_data_array_t *selections = obs_data_get_array(settings, SETTING_SELECTION_MULTIPLE);
+	if (obs_data_array_count(selections) == 0) {
+		obs_data_array_release(selections);
+
+		selections = obs_data_array_create();
+		obs_data_set_array(settings, SETTING_SELECTION_MULTIPLE, selections);
 	}
 
-	obs_pw_audio_proxy_list_init(&pwac->targets, NULL, node_destroy_cb);
-	obs_pw_audio_proxy_list_init(&pwac->clients, NULL, client_destroy_cb);
-	obs_pw_audio_proxy_list_init(&pwac->sink.links, link_bound_cb, link_destroy_cb);
-	obs_pw_audio_proxy_list_init(&pwac->system_sinks, NULL, system_sink_destroy_cb);
+	/* Don't add if selection is already in the list */
 
-	pwac->sink.id = SPA_ID_INVALID;
-	dstr_init(&pwac->sink.position);
+	bool should_add = true;
+	for (size_t i = 0; i < obs_data_array_count(selections) && should_add; i++) {
+		obs_data_t *item = obs_data_array_item(selections, i);
 
-	pwac->match_priority = obs_data_get_int(settings, "MatchPriority");
-	dstr_init_copy(&pwac->target, obs_data_get_string(settings, "TargetName"));
-	pwac->except_app = obs_data_get_bool(settings, "ExceptApp");
+		should_add = astrcmpi(obs_data_get_string(item, "value"), app_to_add) != 0;
 
-	obs_pw_audio_instance_sync(&pwac->pw);
-	pw_thread_loop_wait(pwac->pw.thread_loop);
-	pw_thread_loop_unlock(pwac->pw.thread_loop);
+		obs_data_release(item);
+	}
 
-	return pwac;
-}
+	if (should_add) {
+		obs_data_t *new_entry = obs_data_create();
+		obs_data_set_bool(new_entry, "hidden", false);
+		obs_data_set_bool(new_entry, "selected", false);
+		obs_data_set_string(new_entry, "value", app_to_add);
 
-static void pipewire_audio_capture_app_defaults(obs_data_t *settings)
-{
-	obs_data_set_default_int(settings, "MatchPriority", BINARY_NAME);
-	obs_data_set_default_bool(settings, "ExceptApp", false);
+		obs_data_array_push_back(selections, new_entry);
+
+		obs_data_release(new_entry);
+
+		obs_source_update(source, settings);
+	}
+
+	obs_data_array_release(selections);
+	obs_data_release(settings);
+
+	return should_add;
 }
 
 static int cmp_targets(const void *a, const void *b)
@@ -819,33 +832,26 @@ static const char *choose_display_string(struct obs_pw_audio_capture_app *pwac,
 										 const char *app_name)
 {
 	switch (pwac->match_priority) {
-	case BINARY_NAME:
+	case MATCH_PRIORITY_BINARY_NAME:
 		return binary ? binary : app_name;
-	case APP_NAME:
+	case MATCH_PRIORITY_APP_NAME:
 		return app_name ? app_name : binary;
+	default:
+		return NULL;
 	}
 }
 
-static bool match_priority_modified(void *data, obs_properties_t *properties, obs_property_t *property,
-									obs_data_t *settings)
+static void populate_avaiable_apps_list(obs_property_t *list, struct obs_pw_audio_capture_app *pwac)
 {
-	UNUSED_PARAMETER(property);
-	UNUSED_PARAMETER(settings);
-
-	struct obs_pw_audio_capture_app *pwac = data;
-
-	obs_property_t *targets = obs_properties_get(properties, "TargetName");
-	obs_property_list_clear(targets);
-
-	DARRAY(char *) targets_arr;
-	da_init(targets_arr);
+	DARRAY(const char *) targets;
+	da_init(targets);
 
 	pw_thread_loop_lock(pwac->pw.thread_loop);
 
-	da_reserve(targets_arr, pwac->n_targets);
+	da_reserve(targets, pwac->n_nodes);
 
 	struct obs_pw_audio_proxy_list_iter iter;
-	obs_pw_audio_proxy_list_iter_init(&iter, &pwac->targets);
+	obs_pw_audio_proxy_list_iter_init(&iter, &pwac->nodes);
 
 	struct target_node *node;
 	while (obs_pw_audio_proxy_list_iter_next(&iter, (void **)&node)) {
@@ -855,7 +861,7 @@ static bool match_priority_modified(void *data, obs_properties_t *properties, ob
 			display = node->name;
 		}
 
-		da_push_back(targets_arr, &display);
+		da_push_back(targets, &display);
 	}
 
 	obs_pw_audio_proxy_list_iter_init(&iter, &pwac->clients);
@@ -865,45 +871,199 @@ static bool match_priority_modified(void *data, obs_properties_t *properties, ob
 		const char *display = choose_display_string(pwac, client->binary, client->app_name);
 
 		if (display) {
-			da_push_back(targets_arr, &display);
+			da_push_back(targets, &display);
 		}
 	}
 
 	/* Show just one entry per target */
 
-	qsort(targets_arr.array, targets_arr.num, sizeof(char *), cmp_targets);
+	qsort(targets.array, targets.num, sizeof(const char *), cmp_targets);
 
-	for (size_t i = 0; i < targets_arr.num; i++) {
-		if (i == 0 || strcmp(targets_arr.array[i - 1], targets_arr.array[i]) != 0) {
-			obs_property_list_add_string(targets, targets_arr.array[i], NULL);
+	for (size_t i = 0; i < targets.num; i++) {
+		if (i == 0 || strcmp(targets.array[i - 1], targets.array[i]) != 0) {
+			obs_property_list_add_string(list, targets.array[i], targets.array[i]);
 		}
 	}
 
 	pw_thread_loop_unlock(pwac->pw.thread_loop);
 
-	da_free(targets_arr);
+	da_free(targets);
+}
+
+static bool capture_mode_modified(void *data, obs_properties_t *properties, obs_property_t *property,
+								  obs_data_t *settings)
+{
+	UNUSED_PARAMETER(property);
+
+	struct obs_pw_audio_capture_app *pwac = data;
+
+	enum capture_mode mode = obs_data_get_int(settings, SETTING_CAPTURE_MODE);
+
+	switch (mode) {
+	case CAPTURE_MODE_SINGLE: {
+		obs_properties_remove_by_name(properties, SETTING_SELECTION_MULTIPLE);
+		obs_properties_remove_by_name(properties, SETTING_AVAILABLE_APPS);
+		obs_properties_remove_by_name(properties, SETTING_ADD_TO_SELECTIONS);
+
+		obs_property_t *available_apps = obs_properties_add_list(properties, SETTING_SELECTION_SINGLE,
+																 obs_module_text("Application"),
+																 OBS_COMBO_TYPE_EDITABLE, OBS_COMBO_FORMAT_STRING);
+
+		populate_avaiable_apps_list(available_apps, pwac);
+
+		break;
+	}
+	case CAPTURE_MODE_MULTIPLE: {
+		obs_properties_remove_by_name(properties, SETTING_SELECTION_SINGLE);
+
+		obs_properties_add_editable_list(properties, SETTING_SELECTION_MULTIPLE, obs_module_text("SelectedApps"),
+										 OBS_EDITABLE_LIST_TYPE_STRINGS, NULL, NULL);
+
+		obs_property_t *available_apps = obs_properties_add_list(properties, SETTING_AVAILABLE_APPS,
+																 obs_module_text("Applications"), OBS_COMBO_TYPE_LIST,
+																 OBS_COMBO_FORMAT_STRING);
+
+		populate_avaiable_apps_list(available_apps, pwac);
+
+		obs_properties_add_button2(properties, SETTING_ADD_TO_SELECTIONS, obs_module_text("AddToSelected"),
+								   add_app_clicked, pwac->source);
+
+		break;
+	}
+	}
 
 	return true;
 }
 
+static bool match_priority_modified(void *data, obs_properties_t *properties, obs_property_t *property,
+									obs_data_t *settings)
+{
+	UNUSED_PARAMETER(property);
+
+	struct obs_pw_audio_capture_app *pwac = data;
+
+	enum capture_mode mode = obs_data_get_int(settings, SETTING_CAPTURE_MODE);
+
+	obs_property_t *targets = NULL;
+	switch (mode) {
+	default:
+	case CAPTURE_MODE_SINGLE:
+		targets = obs_properties_get(properties, SETTING_SELECTION_SINGLE);
+		break;
+	case CAPTURE_MODE_MULTIPLE:
+		targets = obs_properties_get(properties, SETTING_AVAILABLE_APPS);
+		break;
+	}
+
+	if (targets == NULL) {
+		return false;
+	}
+
+	obs_property_list_clear(targets);
+
+	populate_avaiable_apps_list(targets, pwac);
+
+	return true;
+}
+
+static void build_selections(struct obs_pw_audio_capture_app *pwac, obs_data_t *settings)
+{
+	switch (pwac->capture_mode) {
+	case CAPTURE_MODE_SINGLE: {
+		const char *selection = bstrdup(obs_data_get_string(settings, SETTING_SELECTION_SINGLE));
+		da_push_back(pwac->selections, &selection);
+		break;
+	}
+	case CAPTURE_MODE_MULTIPLE: {
+		obs_data_array_t *selections = obs_data_get_array(settings, SETTING_SELECTION_MULTIPLE);
+		for (size_t i = 0; i < obs_data_array_count(selections); i++) {
+			obs_data_t *item = obs_data_array_item(selections, i);
+
+			const char *selection = bstrdup(obs_data_get_string(item, "value"));
+			da_push_back(pwac->selections, &selection);
+
+			obs_data_release(item);
+		}
+		obs_data_array_release(selections);
+		break;
+	}
+	}
+}
+
+static void clear_selections(struct obs_pw_audio_capture_app *pwac)
+{
+	for (size_t i = 0; i < pwac->selections.num; i++) {
+		const char *selection = pwac->selections.array[i];
+		bfree((void *)selection);
+	}
+
+	pwac->selections.num = 0;
+}
+
+static void *pipewire_audio_capture_app_create(obs_data_t *settings, obs_source_t *source)
+{
+	struct obs_pw_audio_capture_app *pwac = bzalloc(sizeof(struct obs_pw_audio_capture_app));
+
+	if (!obs_pw_audio_instance_init(&pwac->pw, &registry_events, pwac, true, false, source)) {
+		obs_pw_audio_instance_destroy(&pwac->pw);
+
+		bfree(pwac);
+		return NULL;
+	}
+
+	pwac->source = source;
+
+	obs_pw_audio_proxy_list_init(&pwac->nodes, NULL, node_destroy_cb);
+	obs_pw_audio_proxy_list_init(&pwac->clients, NULL, client_destroy_cb);
+	obs_pw_audio_proxy_list_init(&pwac->sink.links, link_bound_cb, link_destroy_cb);
+	obs_pw_audio_proxy_list_init(&pwac->system_sinks, NULL, system_sink_destroy_cb);
+
+	pwac->sink.id = SPA_ID_INVALID;
+	dstr_init(&pwac->sink.position);
+
+	pwac->capture_mode = obs_data_get_int(settings, SETTING_CAPTURE_MODE);
+	pwac->match_priority = obs_data_get_int(settings, SETTING_MATCH_PRIORITY);
+	pwac->except = obs_data_get_bool(settings, SETTING_EXCLUDE_SELECTIONS);
+
+	da_init(pwac->selections);
+	build_selections(pwac, settings);
+
+	pw_thread_loop_unlock(pwac->pw.thread_loop);
+
+	return pwac;
+}
+
+static void pipewire_audio_capture_app_defaults(obs_data_t *settings)
+{
+	obs_data_set_default_int(settings, SETTING_CAPTURE_MODE, CAPTURE_MODE_SINGLE);
+	obs_data_set_default_int(settings, SETTING_MATCH_PRIORITY, MATCH_PRIORITY_BINARY_NAME);
+	obs_data_set_default_bool(settings, SETTING_EXCLUDE_SELECTIONS, false);
+
+	obs_data_array_t *arr = obs_data_array_create();
+	obs_data_set_default_array(settings, SETTING_SELECTION_MULTIPLE, arr);
+	obs_data_array_release(arr);
+}
+
 static obs_properties_t *pipewire_audio_capture_app_properties(void *data)
 {
 	struct obs_pw_audio_capture_app *pwac = data;
 
 	obs_properties_t *p = obs_properties_create();
 
-	obs_property_t *match_priority = obs_properties_add_list(p, "MatchPriority", obs_module_text("MatchPriority"),
-															 OBS_COMBO_TYPE_LIST, OBS_COMBO_FORMAT_INT);
-	obs_property_list_add_int(match_priority, obs_module_text("MatchBinaryFirst"), BINARY_NAME);
-	obs_property_list_add_int(match_priority, obs_module_text("MatchAppNameFirst"), APP_NAME);
-
-	obs_properties_add_list(p, "TargetName", obs_module_text("Application"), OBS_COMBO_TYPE_EDITABLE,
-							OBS_COMBO_FORMAT_STRING);
-
-	obs_properties_add_bool(p, "ExceptApp", obs_module_text("ExceptApp"));
+	obs_property_t *capture_mode = obs_properties_add_list(p, SETTING_CAPTURE_MODE, obs_module_text("AppCaptureMode"),
+														   OBS_COMBO_TYPE_LIST, OBS_COMBO_FORMAT_INT);
+	obs_property_list_add_int(capture_mode, obs_module_text("SingleApp"), CAPTURE_MODE_SINGLE);
+	obs_property_list_add_int(capture_mode, obs_module_text("MultipleApps"), CAPTURE_MODE_MULTIPLE);
+	obs_property_set_modified_callback2(capture_mode, capture_mode_modified, pwac);
 
+	obs_property_t *match_priority = obs_properties_add_list(
+		p, SETTING_MATCH_PRIORITY, obs_module_text("MatchPriority"), OBS_COMBO_TYPE_LIST, OBS_COMBO_FORMAT_INT);
+	obs_property_list_add_int(match_priority, obs_module_text("MatchBinaryFirst"), MATCH_PRIORITY_BINARY_NAME);
+	obs_property_list_add_int(match_priority, obs_module_text("MatchAppNameFirst"), MATCH_PRIORITY_APP_NAME);
 	obs_property_set_modified_callback2(match_priority, match_priority_modified, pwac);
 
+	obs_properties_add_bool(p, SETTING_EXCLUDE_SELECTIONS, obs_module_text("ExceptApp"));
+
 	return p;
 }
 
@@ -911,21 +1071,17 @@ static void pipewire_audio_capture_app_update(void *data, obs_data_t *settings)
 {
 	struct obs_pw_audio_capture_app *pwac = data;
 
-	pwac->match_priority = obs_data_get_int(settings, "MatchPriority");
-	const char *new_target = obs_data_get_string(settings, "TargetName");
-	bool except = obs_data_get_bool(settings, "ExceptApp");
-
 	pw_thread_loop_lock(pwac->pw.thread_loop);
 
-	if (except == pwac->except_app && dstr_cmpi(&pwac->target, new_target) == 0) {
-		pw_thread_loop_unlock(pwac->pw.thread_loop);
-		return;
-	}
+	pwac->capture_mode = obs_data_get_int(settings, SETTING_CAPTURE_MODE);
+	pwac->match_priority = obs_data_get_int(settings, SETTING_MATCH_PRIORITY);
+	pwac->except = obs_data_get_bool(settings, SETTING_EXCLUDE_SELECTIONS);
 
-	connect_targets(pwac, new_target, except);
+	clear_selections(pwac);
+	build_selections(pwac, settings);
+
+	connect_targets(pwac);
 
-	obs_pw_audio_instance_sync(&pwac->pw);
-	pw_thread_loop_wait(pwac->pw.thread_loop);
 	pw_thread_loop_unlock(pwac->pw.thread_loop);
 }
 
@@ -953,7 +1109,7 @@ static void pipewire_audio_capture_app_destroy(void *data)
 
 	pw_thread_loop_lock(pwac->pw.thread_loop);
 
-	obs_pw_audio_proxy_list_clear(&pwac->targets);
+	obs_pw_audio_proxy_list_clear(&pwac->nodes);
 	obs_pw_audio_proxy_list_clear(&pwac->system_sinks);
 
 	obs_pw_audio_proxy_list_clear(&pwac->clients);
@@ -970,7 +1126,9 @@ static void pipewire_audio_capture_app_destroy(void *data)
 	obs_pw_audio_instance_destroy(&pwac->pw);
 
 	dstr_free(&pwac->sink.position);
-	dstr_free(&pwac->target);
+
+	clear_selections(pwac);
+	da_free(pwac->selections);
 
 	bfree(pwac);
 }
