@@ -201,7 +201,7 @@ static void on_process_cb(void *data)
 		out.data[i] = buf->datas[i].data;
 	}
 
-	if (s->info.sample_rate * s->pos->clock.rate_diff) {
+	if (s->info.sample_rate && s->pos->clock.rate_diff) {
 		/** Taken from PipeWire's implementation of JACK's jack_get_cycle_times
 		  * (https://gitlab.freedesktop.org/pipewire/pipewire/-/blob/0.3.52/pipewire-jack/src/pipewire-jack.c#L5639)
 		  * which is used in the linux-jack plugin to correctly set the timestamp
@@ -280,9 +280,9 @@ int obs_pw_audio_stream_connect(struct obs_pw_audio_stream *s, uint32_t target_i
 		SPA_FORMAT_mediaSubtype, SPA_POD_Id(SPA_MEDIA_SUBTYPE_raw), SPA_FORMAT_AUDIO_channels,
 		SPA_POD_Int(audio_channels), SPA_FORMAT_AUDIO_position,
 		SPA_POD_Array(sizeof(enum spa_audio_channel), SPA_TYPE_Id, audio_channels, pos), SPA_FORMAT_AUDIO_format,
-		SPA_POD_CHOICE_ENUM_Id(8, SPA_AUDIO_FORMAT_U8, SPA_AUDIO_FORMAT_S16_LE, SPA_AUDIO_FORMAT_S32_LE,
-							   SPA_AUDIO_FORMAT_F32_LE, SPA_AUDIO_FORMAT_U8P, SPA_AUDIO_FORMAT_S16P,
-							   SPA_AUDIO_FORMAT_S32P, SPA_AUDIO_FORMAT_F32P));
+		SPA_POD_CHOICE_ENUM_Id(9, SPA_AUDIO_FORMAT_F32P, SPA_AUDIO_FORMAT_U8, SPA_AUDIO_FORMAT_S16_LE,
+							   SPA_AUDIO_FORMAT_S32_LE, SPA_AUDIO_FORMAT_F32_LE, SPA_AUDIO_FORMAT_U8P,
+							   SPA_AUDIO_FORMAT_S16P, SPA_AUDIO_FORMAT_S32P, SPA_AUDIO_FORMAT_F32P));
 
 	struct pw_properties *stream_props = pw_properties_new(NULL, NULL);
 	pw_properties_setf(stream_props, PW_KEY_TARGET_OBJECT, "%u", target_serial);
@@ -348,13 +348,15 @@ bool obs_pw_audio_instance_init(struct obs_pw_audio_instance *pw, const struct p
 	}
 	pw_registry_add_listener(pw->registry, &pw->registry_listener, registry_events, registry_cb_data);
 
+	struct pw_properties *stream_props = pw_properties_new(
+		PW_KEY_MEDIA_NAME, obs_source_get_name(stream_output), PW_KEY_MEDIA_TYPE, "Audio", PW_KEY_MEDIA_CATEGORY,
+		"Capture", PW_KEY_MEDIA_ROLE, "Production", PW_KEY_NODE_WANT_DRIVER, stream_want_driver ? "true" : "false",
+		PW_KEY_STREAM_CAPTURE_SINK, stream_capture_sink ? "true" : "false", NULL);
+
+	pw_properties_setf(stream_props, PW_KEY_NODE_NAME, "OBS: %s", obs_source_get_name(stream_output));
+
 	pw->audio.output = stream_output;
-	pw->audio.stream =
-		pw_stream_new(pw->core, "OBS",
-					  pw_properties_new(PW_KEY_NODE_NAME, "OBS", PW_KEY_NODE_DESCRIPTION, "OBS Audio Capture",
-										PW_KEY_MEDIA_TYPE, "Audio", PW_KEY_MEDIA_CATEGORY, "Capture", PW_KEY_MEDIA_ROLE,
-										"Production", PW_KEY_NODE_WANT_DRIVER, stream_want_driver ? "true" : "false",
-										PW_KEY_STREAM_CAPTURE_SINK, stream_capture_sink ? "true" : "false", NULL));
+	pw->audio.stream = pw_stream_new(pw->core, obs_source_get_name(stream_output), stream_props);
 
 	if (!pw->audio.stream) {
 		blog(LOG_WARNING, "[pipewire] Failed to create stream");
